@@ -28,5 +28,8 @@ test_that("iucn_id fails well", {
   }
 
   expect_error(iucn_id(), "argument \"sciname\" is missing")
-  expect_equal(suppressWarnings(iucn_id("foo bar")), NA)
+  
+  vcr::use_cassette("iucn_id_fail", {
+    expect_equal(suppressWarnings(iucn_id("foo bar")), NA)
+  })
 })
